All keys and passwords should be replaceable
-------

**Description:**

It always can happen that you need the keys or the passwords of the application or in components 
that are needed by the application to work in a secure state. When these keys needs to be revoked
because the password was leaked or an administrator leaving the company it's always smart to have
the possibility to revoke the keys or passwords without to much problems.

**Solution:**

Verify in the application and components it uses that it's possible to replace the used keys and
passwords. Also replace default keys and passwords after the installation of the application.
